.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2018-01-05)
++++++++++++++++++

`0.2.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0>`_

* Added REST API filters.
* Added URLs to pubmed article and NCBI utils.

0.2.1 (2018-01-09)
++++++++++++++++++

`0.2.1 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.0...v0.2.1>`_

* Fixed issues with migrations

0.2.2 (2018-01-12)
++++++++++++++++++

`0.2.2 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.1...v0.2.2>`_

* Fixed route names for SimpleRouter.

0.3.0 (2018-02-09)
++++++++++++++++++

`0.3.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.2.2...v0.3.0>`_

* updated requirements to the latest.

0.4.0 (2018-04-03)
++++++++++++++++++

`0.4.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.3.0...v0.4.0>`_

* Added support for GraphQL

0.5.0 (2018-04-07)
++++++++++++++++++

`0.5.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.4.0...v0.5.0>`_

* Added support for Django 2.0 and Python 3.6
* Dropped support for Django < 1.11 and Python 2.7, 3.3, 3.4

0.5.1 (2018-04-18)
++++++++++++++++++

`0.5.1 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.5.0...v0.5.1>`_

* Updated 3rd party libs

0.5.2 (2018-05-16)
++++++++++++++++++

`0.5.2 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.5.1...v0.5.2>`_

* Updated 3rd party libs
* Updated setup.py to read requirements from requirements.txt

0.6.0 (2018-06-01)
++++++++++++++++++

`0.6.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.5.2...v0.6.0>`_

* Dropped support for GraphQL

0.6.1 (2018-08-13)
++++++++++++++++++

`0.6.1 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.6.0...v0.6.1>`_

* Updated 3rd party requirements. Some requirements had changed so it was causing failures

0.6.2 (2018-10-29)
++++++++++++++++++

`0.6.2 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.6.1...v0.6.2>`_

* Updated 3rd party requirements.

0.7.0 (2018-12-05)
++++++++++++++++++

`0.7.0 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.6.2...v0.7.0>`_

* Added attribute to save PDF for an article
* Added REST API to summarize all details from eutils (efetch and esummary) into a single API call

0.7.1 (2018-12-05)
++++++++++++++++++

`0.7.1 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.0...v0.7.1>`_

* Added REST API to summarize all details from eutils (efetch and esummary) into a single API call

0.7.2 (2019-01-08)
++++++++++++++++++

`0.7.2 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.1...v0.7.2>`_

* Updated 3rd party requirements.

0.7.3 (2019-02-08)
++++++++++++++++++

`0.7.3 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.2...v0.7.3>`_

* Updated 3rd party requirements.
* Refactored tests

0.7.4 (2019-04-10)
++++++++++++++++++

`0.7.4 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.3...v0.7.4>`_

* Updated 3rd party requirements.
* Updated travis to use xenial distribution. Django 2.1 dropped support for SQLite < 3.8.3

0.7.5 (2019-05-31)
++++++++++++++++++

`0.7.5 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.4...v0.7.5>`_

* Updated package to use latest cookiecutter template

0.7.6 (2019-07-26)
++++++++++++++++++

`0.7.6 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.5...v0.7.6>`_

* Updated 3rd party requirements.

0.7.7 (2019-08-09)
++++++++++++++++++

`0.7.7 Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.7.6...v0.7.7>`_

* Updated 3rd party requirements.
